@@ -2,7 +2,7 @@ package Crypt::OpenPGP;
 use strict;
 use 5.008_001;
 
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 use Crypt::OpenPGP::Constants qw( DEFAULT_CIPHER );
 use Crypt::OpenPGP::KeyRing;
@@ -529,7 +529,9 @@ sub encrypt {
         } else {
             $s2k = Crypt::OpenPGP::S2k->new('Salt_Iter');
         }
-        my $keysize = Crypt::OpenPGP::Cipher->new($sym_alg)->keysize;
+        my $cipher = Crypt::OpenPGP::Cipher->new($sym_alg) or
+            return $pgp->error( Crypt::OpenPGP::Cipher->errstr );
+        my $keysize = $cipher->keysize;
         $key_data = $s2k->generate($pass, $keysize);
         push @sym_keys, Crypt::OpenPGP::SKSessionKey->new(
                             Passphrase => $pass,
