@@ -1,5 +1,3 @@
-# $Id: Signature.pm,v 1.18 2002/10/12 22:02:29 btrott Exp $
-
 package Crypt::OpenPGP::Signature;
 use strict;
 
@@ -277,20 +275,15 @@ Crypt::OpenPGP::Signature - Signature packet
 
     use Crypt::OpenPGP::Signature;
 
+    my $cert = Crypt::OpenPGP::Certificate->new;
+    my $plaintext = 'foo bar';
+
     my $sig = Crypt::OpenPGP::Signature->new(
-                               Key  => $secret_key,
-                               Data => $plaintext,
-                               Type => 0x00,
-                     );
+        Key  => $cert,
+        Data => $plaintext,
+    );
     my $serialized = $sig->save;
 
-    my $sig = Crypt::OpenPGP::Signature->parse($buffer);
-    my $hashed_data = $sig->hash_data($plaintext);
-
-    ## Look up public key by $sig->key_id to get $cert, then...
-
-    my $is_valid_sig = $cert->key->verify($sig, $hashed_data);
-
 =head1 DESCRIPTION
 
 I<Crypt::OpenPGP::Signature> implements PGP signature packets and
